pub struct OrderByPositional;Trait Implementations
Sourceimpl Rule for OrderByPositional
impl Rule for OrderByPositional
fn meta(&self) -> &'static RuleMeta
Sourcefn check_query(
&self,
query: &Query,
_depth: usize,
ctx: &LintCtx<'_>,
out: &mut Vec<Diagnostic>,
)
fn check_query( &self, query: &Query, _depth: usize, ctx: &LintCtx<'_>, out: &mut Vec<Diagnostic>, )
depth is 0 for the outermost Query of a statement and increases for
nested queries (subqueries, derived tables, CTEs, scalar subqueries).
Rules that should only flag nested constructs can guard on depth > 0.fn check_statement( &self, _stmt: &SqltStatement, _ctx: &LintCtx<'_>, _out: &mut Vec<Diagnostic>, )
fn check_select( &self, _select: &Select, _ctx: &LintCtx<'_>, _out: &mut Vec<Diagnostic>, )
fn check_expr( &self, _expr: &Expr, _ctx: &LintCtx<'_>, _out: &mut Vec<Diagnostic>, )